@@ -17,7 +17,7 @@ using namespace apolloron;
 
 const char *INKF_PROGNAME = "inkf";
 const char *INKF_BRIEF    = "Yet Another Network Kanji Filter";
-const char *INKF_VERSION  = "2.0.3";
+const char *INKF_VERSION  = "2.0.4";
 const char *INKF_COPY     = "Copyright (C) 2002-2018 Masashi Astro Tachibana";
 const char *INKF_DEF_OUT  = "inkf.out";
 
@@ -772,8 +772,16 @@ void convert(String &str, TOption &option, FILE *fpout) {
     }
     str.gc();
     if (option.mime_encode == MIME_BASE64) {
+        u8str = str.strconv(option.output_charset, "UTF-8");
+        if (0 < u8str.len() && option.flag_no_return_param == false && u8str.search("\n") == u8str.searchR("\n") && u8str[u8str.len()-1] == '\n'){
+            str = u8str.changeReturnCode("").strconv("UTF-8", option.output_charset);
+        }
         str = str.encodeBASE64();
     } else if (option.mime_encode == MIME_QUOTED_PRINTABLE) {
+        u8str = str.strconv(option.output_charset, "UTF-8");
+        if (0 < u8str.len() && option.flag_no_return_param == false && u8str.search("\n") == u8str.searchR("\n") && u8str[u8str.len()-1] == '\n'){
+            str = u8str.changeReturnCode("").strconv("UTF-8", option.output_charset);
+        }
         str = str.encodeQuotedPrintable();
     } else if (option.mime_encode == MIME_BASE64_FULL) {
         u8str = str.strconv(option.output_charset, "UTF-8");
@@ -942,6 +950,8 @@ void show_help() {
       " Z              Convert JISX0208 Alphabet to ASCII\n"
       " O              Output to File (DEFAULT '%s')\n"
       " L[uwm]         Line mode u:LF w:CRLF m:CR (DEFAULT noconversion)\n"
+      " N              Do not remove return-code when decoding/encoding MIME\n"
+      " n              Do not append extra return-code\n"
       " t <encoding>   Specify output encoding (iconv compatible)\n"
       " f <encoding>   Specify input encoding (iconv compatible)\n"
       " --oc=<encoding>    Specify the output encoding\n"
